﻿// Copyright (c) Pixel Crushers. All rights reserved.

using UnityEngine;
using System;
using DG.Tweening;
using BlueGoo.Dialogue;

namespace PixelCrushers.DialogueSystem {
	/// <summary>
	/// Standard UI implementation of IBarkUI.
	/// </summary>

	//[AddComponentMenu("")] // Use wrapper.
	public class CustomStandardBarkUI : StandardBarkUI {
		// Private vars
		private RectTransform rect;

		[Header("Custom settings ")]
		[SerializeField]
		private float durationShow = 0.3f;

		[SerializeField]
		private float durationHide = 0.3f;

		[SerializeField]
		private Ease curveShow;

		[SerializeField]
		private Ease curveHide;

		private enum BubbleType {
			Speak,
			Think
		}
		
		[SerializeField]
		private float delayAfterBark = 2f;


		[SerializeField]
		private BubbleType bubbleType = BubbleType.Speak;

		private void Start() {
			rect = canvas.GetComponent<RectTransform>();
			// Hide on start
			canvasGroup.alpha = 0;
			rect.localScale = new Vector3(0,0,0);

		}

		public override void Bark(Subtitle subtitle) {
			if (ShouldShowText(subtitle)) {
				SetUIElementsActive(false);
				string subtitleText = subtitle.formattedText.text;

				if (includeName) {
					if (nameText != null) {
						nameText.text = subtitle.speakerInfo.Name;
					}
				} else {
					if (nameText != null && nameText.gameObject != null) nameText.gameObject.SetActive(false);
				}

				if (showPortraitImage && subtitle.speakerInfo.portrait != null) {
					Tools.SetGameObjectActive(portraitImage, true);
					portraitImage.sprite = subtitle.speakerInfo.portrait;
				} else {
					Tools.SetGameObjectActive(portraitImage, false);
				}

				if (barkText != null) barkText.text = subtitleText;
				SetUIElementsActive(true);

				CancelInvoke("Hide");

				rect.DOScale(new Vector3(1, 1, 1), durationShow).SetEase(curveShow);
				DOTween.To(() => canvasGroup.alpha, x => canvasGroup.alpha = x, 1.0f, durationShow).SetEase(curveShow);

				// TODO: Räkna ut ny tid med ... och sånt
				var barkDuration = Mathf.Approximately(0, duration) ? DialogueUtils.GetSubtitleDuration(subtitleText) : duration;

				if (!(waitUntilSequenceEnds || waitForContinueButton)) {
					Debug.Log(Time.time.ToString("F1")  + ": Invoke Hide in " + (barkDuration + delayAfterBark) + " seconds");
					Invoke("Hide", barkDuration + delayAfterBark);
					
				}
				if (waitUntilSequenceEnds) numSequencesActive++;
				doneTime = waitForContinueButton ? Mathf.Infinity : (DialogueTime.time + barkDuration + delayAfterBark);
			}
		}

		public override void Hide() {
			Debug.Log(Time.time.ToString("F1") + ": Hide running!");
			rect.DOScale(new Vector3(0, 0, 0), durationHide).SetEase(curveHide);
			DOTween.To(() => canvasGroup.alpha, x => canvasGroup.alpha = x, 0f, durationHide).SetEase(curveHide);

			numSequencesActive = 0;
			doneTime = 0;
		}
	}
}