﻿using PixelCrushers.DialogueSystem;
using UnityEngine;
using System.Text.RegularExpressions;


namespace BlueGoo.Dialogue {
	

	public class DialogueUtils : MonoBehaviour {

		private static float fullPauseDuration = 0.7f;
		private static float quarterPauseDuration = 0.25f;
		
		/// <summary>
		/// Returns the duration that a string of bark text will be shown, including waiting for stop chars.
		/// </summary>
		/// <param name="text">The text that will be barked (to determine the duration).</param>
		/// <returns>The default duration in seconds for the specified bark text.</returns>
		public static float GetSubtitleDuration(string text)
		{
			var minSecs = DialogueManager.instance.displaySettings.barkSettings.minBarkSeconds;
			if (Mathf.Approximately(0, minSecs)) minSecs = DialogueManager.instance.displaySettings.subtitleSettings.minSubtitleSeconds;
			var charsPerSec = DialogueManager.instance.displaySettings.barkSettings.barkCharsPerSecond;
			if (Mathf.Approximately(0, charsPerSec)) charsPerSec = DialogueManager.instance.displaySettings.subtitleSettings.subtitleCharsPerSecond;
			
			// Add duration for stop chars
			var fullPauseDelay = Regex.Matches(text, @"[\.|?|!]").Count * fullPauseDuration;
			var quarterPauseDelay = Regex.Matches(text, @"[,]").Count * quarterPauseDuration;

			
			float duration = string.IsNullOrEmpty(text) ? 0 : Mathf.Max(minSecs, text.Length / charsPerSec);
			Debug.Log("Pause before: " + duration + " - Pause after " + (duration + fullPauseDelay + quarterPauseDelay));
			return duration + fullPauseDelay + quarterPauseDelay;
		}
	}
}


    


